pub enum Error {
ClaimFailure,
StopCalledByClone,
BackendWithNoConnection,
ConnectionRetrievalFailure,
// some variants omitted
}Expand description
The cueball Error type is an enum that represents the different errors
that may be returned by the cueball API.
Variants
ClaimFailure
The call to claim to failed to retrieve a connection within the specified timeout period.
StopCalledByClone
The stop function was called on a pool clone. Only the original
connction pool instance may stop a connection pool. Thread JoinHandles
may not be cloned and therefore invocation of this function by a clone
of the pool results in an error.
BackendWithNoConnection
A backend key was found with no associated connection. This error should never happen and is only represented for completeness. Please file a bug if it is encountered.
ConnectionRetrievalFailure
A connection could not be retrieved from the connection pool even though the connection pool accounting indicated one should be available. This error should never happen and is only represented for completeness. Please file a bug if it is encountered.